# Changelog

## [2.0.28](https://github.com/mdn/data/compare/v2.0.27...v2.0.28) (2022-07-12)


### Bug Fixes

* **css:** correct two syntax examples in selectors ([#589](https://github.com/mdn/data/issues/589)) ([91ab33a](https://github.com/mdn/data/commit/91ab33a40bf2dfd75286a01785453705105533e8))

### [2.0.27](https://github.com/mdn/data/compare/v2.0.26...v2.0.27) (2022-02-24)


### Miscellaneous Chores

* release ([a99ae2e](https://github.com/mdn/data/commit/a99ae2ebfeb930524c18f8d46954e8e32ab6b630))

### [2.0.26](https://www.github.com/mdn/data/compare/v2.0.25...v2.0.26) (2022-01-19)


### Miscellaneous Chores

* release 2.0.26 ([8b1045d](https://www.github.com/mdn/data/commit/8b1045dc488c7b278c933143efd1bdba75b6832f))

### [2.0.25](https://www.github.com/mdn/data/compare/v2.0.24...v2.0.25) (2021-12-21)


### Bug Fixes

* change branch reference to main ([a473261](https://www.github.com/mdn/data/commit/a473261308cf82ee387cec886c70ef3d570fc957))
* remove old clashing workflow ([af9a18c](https://www.github.com/mdn/data/commit/af9a18ce3af2cbca83582debf3c3d3fc0ace7402))


### Miscellaneous Chores

* release 2.0.25 ([db5a54b](https://www.github.com/mdn/data/commit/db5a54ba4f3c28b52d0801e115fd5ff0a0052743))
* release 2.0.25 ([0f453ee](https://www.github.com/mdn/data/commit/0f453eedadbd9065d552203260210bdfafa9d7ff))

### [2.0.24](https://www.github.com/mdn/data/compare/v2.0.24...v2.0.24) (2021-12-17)


### Miscellaneous Chores

* release 2.0.24 ([4d00c38](https://www.github.com/mdn/data/commit/4d00c386efe1cfbf536bb3bc80fed6d687f9ad04))

### [2.0.24](https://www.github.com/mdn/data/compare/v2.0.23...v2.0.24) (2021-12-15)


### Miscellaneous Chores

* release 2.0.24 ([abff6ff](https://www.github.com/mdn/data/commit/abff6ff0fb88e834c65a2cc05f346b105a9b2e99))
